'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _draftlog = require('draftlog');

var _draftlog2 = _interopRequireDefault(_draftlog);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _prettyTime = require('pretty-time');

var _prettyTime2 = _interopRequireDefault(_prettyTime);

var _cli = require('../utils/cli');

var _utils = require('../utils');

var _request = require('../utils/request');

var _consts = require('../utils/consts');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const globalConsole = console; // eslint-disable-line no-console

class BarsReporter {
  constructor() {
    this.renderT = (0, _utils.throttle)(this.render.bind(this), 1, 100);
    this.drafts = null;
  }

  compiling() {
    // eslint-disable-next-line no-console
    if (!globalConsole.draft) {
      _draftlog2.default.into(globalConsole);
    }

    globalConsole.log();
    this.drafts = [globalConsole.draft(), globalConsole.draft()];
  }

  compiled(context) {
    this.render(context);
  }

  update(context) {
    this.renderT(context);
  }

  render(context) {
    const {
      state,
      options: { stream, name }
    } = context;

    const columns = stream.columns || 80;
    const color = (0, _cli.colorize)(state.color);

    if (!state.isRunning) {
      const color2 = state.progress === 100 ? color : _chalk2.default.grey;

      const line1 = color2(`${_consts.TICK} ${name}`);
      const time = (0, _prettyTime2.default)(state.elapsed, 2);
      const line2 = _chalk2.default.grey(`  Compiled succesfuly in ${time}`);

      this.drafts[0](line1);
      this.drafts[1](line2);
    } else {
      const line1 = [color(_consts.BULLET), color(name), (0, _cli.renderBar)(state.progress, state.color), state.msg, `(${state.progress || 0}%)`, _chalk2.default.grey(state.details && state.details[0] || ''), _chalk2.default.grey(state.details && state.details[1] || '')].join(' ');

      const line2 = state.request ? '  ' + _chalk2.default.grey((0, _cli.ellipsisLeft)((0, _request.formatRequest)(state.request), columns - 2)) : '';

      this.drafts[0](line1);
      this.drafts[1](line2);
    }
  }
}
exports.default = BarsReporter;